# Split.tg API PHP直连方案

本方案提供了一个纯PHP实现的Split.tg API客户端，无需浏览器即可在无界面Linux服务器上运行。

## 文件说明

- `split-api-direct.php` - 主PHP脚本，实现了与Split.tg API的直接交互
- `.env.example` - 环境变量配置示例文件

## 系统要求

- PHP 7.4或更高版本
- PHP cURL扩展
- 有效的Split.tg API访问令牌(access token)

## 配置说明

### 1. 环境变量配置

复制`.env.example`文件为`.env`，并填入您的配置：

```bash
cp .env.example .env
nano .env
```

主要配置项：

- `SPLIT_API_TOKEN` - Split.tg的访问令牌(必填)
- `SPLIT_API_URL` - API基础URL，默认为https://split.tg/api
- `RETRY_COUNT` - 失败重试次数，默认为3
- `RETRY_DELAY` - 重试间隔(毫秒)，默认为3000
- `TIMEOUT` - 请求超时时间(毫秒)，默认为30000
- `LOG_PATH` - 日志保存路径，默认为./logs

### 2. 获取访问令牌(Access Token)

由于Split.tg使用TON钱包认证，您需要在有界面的环境中完成一次性的认证获取token：

1. 在有界面环境中访问Split.tg并完成TON钱包连接
2. 使用浏览器开发者工具，在Network标签页中找到API请求
3. 查看请求头中的`Authorization: Bearer xxx...`，复制token部分
4. 将token配置到`.env`文件或通过命令行参数传入

## 使用方法

### 基本用法

购买Premium会员：

```bash
php split-api-direct.php --telegram-user=用户名 --months=3 --token=YOUR_ACCESS_TOKEN
```

购买Stars：

```bash
php split-api-direct.php --telegram-user=用户名 --stars=100 --token=YOUR_ACCESS_TOKEN
```

### 命令行参数

| 参数 | 说明 | 默认值 |
|------|------|--------|
| `--telegram-user` | Telegram用户名(必填) | - |
| `--months` | Premium会员月数 | 3 |
| `--stars` | Stars数量 | - |
| `--token` | 访问令牌(可选，优先使用环境变量) | - |
| `--api-url` | API基础URL | https://split.tg/api |
| `--log-path` | 日志保存路径 | ./logs |
| `--retry-count` | 失败重试次数 | 3 |
| `--retry-delay` | 重试间隔(毫秒) | 3000 |
| `--timeout` | 请求超时时间(毫秒) | 30000 |
| `--dry-run` | 干运行模式，不实际执行购买 | false |

### 示例

使用环境变量中的token购买3个月Premium：

```bash
php split-api-direct.php --telegram-user=@username --months=3
```

使用命令行参数指定token购买100个Stars：

```bash
php split-api-direct.php --telegram-user=username --stars=100 --token=YOUR_ACCESS_TOKEN
```

干运行模式测试(不实际购买)：

```bash
php split-api-direct.php --telegram-user=@username --months=3 --dry-run=true
```

## 日志

脚本会在指定的日志目录生成详细的运行日志，格式为：

```
split-api-YYYY-MM-DDTHH-MM-SS.log
```

日志内容包括API请求、响应和错误信息，便于排查问题。

## 注意事项

1. 访问令牌(token)有一定的有效期，过期后需要重新获取
2. 请妥善保管您的token，不要泄露给他人
3. 如遇到API错误，请查看日志了解详细信息
4. 建议先使用`--dry-run=true`参数测试脚本功能
